@@ -433,6 +433,15 @@ PluginFormcreatorTranslatableInterface
       return $data;
    }
 
+   protected function setTargetPriority(array $data): array {
+      // Remove default priority so it can be computed
+      if (isset($data['urgency']) || isset($data['impact'])) {
+         unset($data['priority']);
+      }
+      return $data;
+   }
+
+
    /**
     * find all actors and prepare data for the ticket being created
     */
@@ -969,7 +978,7 @@ PluginFormcreatorTranslatableInterface
 
    protected function showCategorySettings($rand) {
       echo '<tr>';
-      echo '<td width="15%">' . PluginFormcreatorCategory::getTypeName(1) . '</td>';
+      echo '<td width="15%">' . ITILCategory::getTypeName(1) . '</td>';
       echo '<td width="25%">';
       Dropdown::showFromArray(
          'category_rule',
@@ -2317,6 +2326,11 @@ SCRIPT;
       }
 
       $data = array_merge($data, $predefined_fields);
+
+      if (($data['requesttypes_id'] ?? 0) == 0) {
+         unset($data['requesttypes_id']);
+      }
+
       return $data;
    }
 
@@ -2484,4 +2498,17 @@ SCRIPT;
    public static function getNoMailImage() {
       return '<i class="fas fa-envelope pointer" title="' . __('Email followup') . ' ' . __('No') . '" width="20"></i>';
    }
+
+   public function getCloneRelations(): array {
+      return [
+         PluginFormcreatorTarget_Actor::class,
+         PluginFormcreatorCondition::class,
+      ];
+   }
+
+   public function prepareInputForClone($input) {
+      $input = parent::prepareInputForClone($input);
+      $input['_skip_create_actors'] = true;
+      return $input;
+   }
 }
