@@ -811,6 +811,26 @@ JAVASCRIPT;
             $newMenu['reservation'] = $menus['reservation'];
          }
       }
+      $reminderTable = Reminder::getTable();
+      $criteria = [
+         'SELECT'   => "$reminderTable.*",
+         'DISTINCT' => true,
+         'FROM'     => $reminderTable,
+         'ORDER'    => "$reminderTable.name"
+      ];
+      $criteria = $criteria + Reminder::getVisibilityCriteria();
+      $criteria['WHERE']["$reminderTable.users_id"] = ['<>', Session::getLoginUserID()];
+      $iterator = $DB->request($criteria);
+      $hasReminder = $iterator->count() > 0;
+
+      if (Reminder::canView() && $hasReminder) {
+         $newMenu['reminders'] = [
+            'default' => Plugin::getWebDir('formcreator', false) . '/front/wizardreminders.php',
+            'title'   => __('Consult reminders', 'formcreator'),
+            'icon'    => 'fa fa-sticky-note',
+         ];
+      }
+
       $rssFeedTable = RSSFeed::getTable();
       $criteria = [
          'SELECT'   => "$rssFeedTable.*",
